@@ -80,10 +80,11 @@ Exceptions
 """
 
 import logging
+import warnings
 from typing import List, Optional, Union
 from datetime import datetime, timedelta
 
-from qiskit.providers import BaseBackend, Backend  # type: ignore[attr-defined]
+from qiskit.providers import Backend  # type: ignore[attr-defined]
 
 from .ibmqfactory import IBMQFactory
 from .ibmqbackend import IBMQBackend
@@ -97,6 +98,17 @@ from .utils.utils import setup_logger
 from .runner_result import RunnerResult
 from .version import __version__
 
+warnings.warn(
+    f"The package {__name__} is being deprecated. "
+    "Please see "
+    "https://ibm.biz/provider_migration_guide"
+    " to get instructions on how to migrate to "
+    "qiskit-ibm-provider (https://github.com/Qiskit/qiskit-ibm-provider) and "
+    "qiskit-ibm-runtime (https://github.com/Qiskit/qiskit-ibm-runtime).",
+    DeprecationWarning,
+    stacklevel=3
+)
+
 # Setup the logger for the IBM Quantum Provider package.
 logger = logging.getLogger(__name__)
 setup_logger(logger)
@@ -114,9 +126,9 @@ QISKIT_IBMQ_PROVIDER_LOG_FILE = 'QISKIT_IBMQ_PROVIDER_LOG_FILE'
 
 
 def least_busy(
-        backends: List[Union[Backend, BaseBackend]],
+        backends: List[Backend],
         reservation_lookahead: Optional[int] = 60
-) -> Union[Backend, BaseBackend]:
+) -> Backend:
     """Return the least busy backend from a list.
 
     Return the least busy available backend for those that
