@@ -142,7 +142,8 @@ class IBMQBackend(Backend):
                        meas_return=MeasReturnType.AVERAGE,
                        memory_slots=None, memory_slot_size=100,
                        rep_time=None, rep_delay=None,
-                       init_qubits=True, use_measure_esp=None)
+                       init_qubits=True, use_measure_esp=None,
+                       live_data_enabled=None)
 
     @deprecate_arguments({'qobj': 'circuits'})
     def run(
@@ -169,6 +170,7 @@ class IBMQBackend(Backend):
             init_qubits: Optional[bool] = None,
             parameter_binds: Optional[List[Dict[Parameter, float]]] = None,
             use_measure_esp: Optional[bool] = None,
+            live_data_enabled: Optional[bool] = None,
             **run_config: Dict
     ) -> IBMQJob:
         """Run on the backend.
@@ -249,6 +251,8 @@ class IBMQBackend(Backend):
                 Default: ``True`` if backend supports ESP readout, else ``False``. Backend support
                 for ESP readout is determined by the flag ``measure_esp_enabled`` in
                 ``backend.configuration()``.
+            live_data_enabled (bool): Activate the live data in the backend, to receive data
+                from the instruments.
             **run_config: Extra arguments used to configure the run.
 
         Returns:
@@ -285,6 +289,14 @@ class IBMQBackend(Backend):
                 "'use_measure_esp' is unset or set to 'False'."
             )
 
+        if run_config.get("dynamic", None) is not None:
+            raise IBMQBackendValueError(
+                "The IBMQ provider is being deprecated and does not support dynamic circuits. "
+                "Please use the qiskit-ibm-provider instead. "
+                "See the documentation for more information on usage - "
+                "https://qiskit.org/documentation/partners/qiskit_ibm_provider/. "
+            )
+
         if not self.configuration().simulator:
             self._deprecate_id_instruction(circuits)
 
@@ -323,7 +335,7 @@ class IBMQBackend(Backend):
                 run_config_dict['method'] = sim_method
             qobj = assemble(circuits, self, **run_config_dict)
 
-        return self._submit_job(qobj, job_name, job_tags, experiment_id)
+        return self._submit_job(qobj, job_name, job_tags, experiment_id, live_data_enabled)
 
     def _get_run_config(self, **kwargs: Any) -> Dict:
         """Return the consolidated runtime configuration."""
@@ -341,7 +353,8 @@ class IBMQBackend(Backend):
             qobj: Union[QasmQobj, PulseQobj],
             job_name: Optional[str] = None,
             job_tags: Optional[List[str]] = None,
-            experiment_id: Optional[str] = None
+            experiment_id: Optional[str] = None,
+            live_data_enabled: Optional[bool] = None
     ) -> IBMQJob:
         """Submit the Qobj to the backend.
 
@@ -353,6 +366,7 @@ class IBMQBackend(Backend):
                 Job names do not need to be unique.
             job_tags: Tags to be assigned to the job.
             experiment_id: Used to add a job to an experiment.
+            live_data_enabled: Used to activate/deactivate live data on the backend.
 
         Returns:
             The job to be executed.
@@ -377,7 +391,8 @@ class IBMQBackend(Backend):
                 qobj_dict=qobj_dict,
                 job_name=job_name,
                 job_tags=job_tags,
-                experiment_id=experiment_id)
+                experiment_id=experiment_id,
+                live_data_enabled=live_data_enabled)
         except ApiError as ex:
             if 'Error code: 3458' in str(ex):
                 raise IBMQBackendJobLimitError('Error submitting job: {}'.format(str(ex))) from ex
@@ -903,6 +918,7 @@ class IBMQSimulator(IBMQBackend):
             except AttributeError:
                 pass
         run_config.update(kwargs)
+
         return super().run(circuits, job_name=job_name,
                            job_tags=job_tags, experiment_id=experiment_id,
                            noise_model=noise_model, **run_config)
