@@ -18,12 +18,13 @@ from typing import Union
 
 import ipyvuetify as vue
 from IPython.display import display  # pylint: disable=import-error
-from qiskit.test.mock.fake_backend import FakeBackend
+from qiskit.providers.fake_provider.fake_backend import FakeBackend
 from qiskit.providers.ibmq.ibmqbackend import IBMQBackend
 from .config_widget import config_tab
 from .qubits_widget import qubits_tab
 from .gates_widget import gates_tab
 from .jobs_widget import jobs_tab
+from .live_data_widget import LiveDataVisualization
 from ..visualization.interactive import iplot_error_map
 
 
@@ -43,8 +44,10 @@ def backend_widget(backend: Union[IBMQBackend, FakeBackend]) -> None:
     Args:
         backend: Display information about this backend.
     """
+    vue.theme.dark = False
     cred = backend._credentials
     last_tab = vue.TabItem(children=[])
+    livedata = LiveDataVisualization()
     card = vue.Card(height=600, outlined=True,
                     children=[
                         vue.Toolbar(flat=True, color="#002d9c",
@@ -61,13 +64,25 @@ def backend_widget(backend: Union[IBMQBackend, FakeBackend]) -> None:
                                      vue.Tab(children=['Qubits']),
                                      vue.Tab(children=['Non-local Gates']),
                                      vue.Tab(children=['Error map']),
+                                     vue.Tab(children=['Live Data']),
                                      vue.Tab(children=['Job Summary']),
                                      vue.TabItem(children=[config_tab(backend)]),
                                      vue.TabItem(children=[qubits_tab(backend)]),
                                      vue.TabItem(children=[gates_tab(backend)]),
-                                     vue.TabItem(children=[iplot_error_map(backend,
-                                                                           figsize=(None, None),
-                                                                           as_widget=True)]),
+                                     vue.TabItem(
+                                         children=[
+                                             iplot_error_map(
+                                                 backend, figsize=(None, None), as_widget=True
+                                             )
+                                         ]
+                                     ),
+                                     vue.TabItem(
+                                         children=[
+                                             livedata.create_visualization(
+                                                 backend, figsize=(11, 9), show_title=False
+                                             )
+                                         ]
+                                     ),
                                      last_tab])
                     ])
 
