@@ -18,7 +18,7 @@ from typing import Union
 
 import ipywidgets as wid
 import plotly.graph_objects as go
-from qiskit.test.mock.fake_backend import FakeBackend
+from qiskit.providers.fake_provider.fake_backend import FakeBackend
 from qiskit.providers.ibmq.ibmqbackend import IBMQBackend
 
 from ..ibmqbackend import IBMQBackend
