@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # This code is part of Qiskit.
 #
 # (C) Copyright IBM 2019.
@@ -17,7 +15,6 @@
 from typing import List, Optional, Union, Tuple, Dict
 import copy
 
-# TODO Use TYPE_CHECKING instead of pylint disable after dropping python 3.5
 import numpy  # pylint: disable=unused-import
 from qiskit.result import Result
 from qiskit.circuit import QuantumCircuit
@@ -57,7 +54,7 @@ class ManagedResults:
         self._job_set = job_set
         self.backend_name = backend_name
         self.success = success
-        self._combined_results = None  # type: Result
+        self._combined_results = None  # type: Optional[Result]
 
     def data(self, experiment: Union[str, QuantumCircuit, Schedule, int]) -> Dict:
         """Get the raw data for an experiment.
