@@ -16,14 +16,16 @@
 
 import base64
 import copy
+import functools
 import importlib
 import inspect
 import io
 import json
+import re
 import warnings
 import zlib
 from datetime import date
-from typing import Any, Callable, Dict, List, Union
+from typing import Any, Callable, Dict, List, Union, Tuple
 
 import dateutil.parser
 import numpy as np
@@ -34,11 +36,65 @@ try:
 except ImportError:
     HAS_SCIPY = False
 
-from qiskit.circuit import (Instruction, ParameterExpression, QuantumCircuit,
-                            qpy_serialization)
-from qiskit.circuit.library import BlueprintCircuit
+from qiskit.circuit import (
+    Instruction,
+    ParameterExpression,
+    ParameterVector,
+    QuantumCircuit,
+    QuantumRegister,
+    qpy_serialization,
+)
 from qiskit.result import Result
 
+from qiskit.version import __version__ as _terra_version_string
+
+
+# This version pattern is taken from the pypa packaging project:
+# https://github.com/pypa/packaging/blob/21.3/packaging/version.py#L223-L254
+# which is dual licensed Apache 2.0 and BSD see the source for the original
+# authors and other details
+VERSION_PATTERN = (
+    "^"
+    + r"""
+    v?
+    (?:
+        (?:(?P<epoch>[0-9]+)!)?                           # epoch
+        (?P<release>[0-9]+(?:\.[0-9]+)*)                  # release segment
+        (?P<pre>                                          # pre-release
+            [-_\.]?
+            (?P<pre_l>(a|b|c|rc|alpha|beta|pre|preview))
+            [-_\.]?
+            (?P<pre_n>[0-9]+)?
+        )?
+        (?P<post>                                         # post release
+            (?:-(?P<post_n1>[0-9]+))
+            |
+            (?:
+                [-_\.]?
+                (?P<post_l>post|rev|r)
+                [-_\.]?
+                (?P<post_n2>[0-9]+)?
+            )
+        )?
+        (?P<dev>                                          # dev release
+            [-_\.]?
+            (?P<dev_l>dev)
+            [-_\.]?
+            (?P<dev_n>[0-9]+)?
+        )?
+    )
+    (?:\+(?P<local>[a-z0-9]+(?:[-_\.][a-z0-9]+)*))?       # local version
+"""
+    + "$"
+)
+_TERRA_VERSION = tuple(
+    int(x) for x in re.search(
+        VERSION_PATTERN,
+        _terra_version_string,
+        re.VERBOSE | re.IGNORECASE
+    ).group("release").split(".")
+)
+
 
 def to_base64_string(data: str) -> str:
     """Convert string to base64 string.
@@ -175,6 +231,8 @@ class RuntimeEncoder(json.JSONEncoder):
         if isinstance(obj, complex):
             return {'__type__': 'complex', '__value__': [obj.real, obj.imag]}
         if isinstance(obj, np.ndarray):
+            if obj.dtype == object:
+                return {"__type__": "ndarray", "__value__": obj.tolist()}
             value = _serialize_and_encode(obj, np.save, allow_pickle=False)
             return {'__type__': 'ndarray', '__value__': value}
         if isinstance(obj, set):
@@ -184,9 +242,6 @@ class RuntimeEncoder(json.JSONEncoder):
         if hasattr(obj, 'to_json'):
             return {'__type__': 'to_json', '__value__': obj.to_json()}
         if isinstance(obj, QuantumCircuit):
-            # TODO Remove the decompose when terra 6713 is released.
-            if isinstance(obj, BlueprintCircuit):
-                obj = obj.decompose()
             value = _serialize_and_encode(
                 data=obj,
                 serializer=lambda buff, data: qpy_serialization.dump(data, buff)
@@ -200,8 +255,13 @@ class RuntimeEncoder(json.JSONEncoder):
             )
             return {'__type__': 'ParameterExpression', '__value__': value}
         if isinstance(obj, Instruction):
+            # Append instruction to empty circuit
+            quantum_register = QuantumRegister(obj.num_qubits)
+            quantum_circuit = QuantumCircuit(quantum_register)
+            quantum_circuit.append(obj, quantum_register)
             value = _serialize_and_encode(
-                data=obj, serializer=qpy_serialization._write_instruction, compress=False)
+                data=quantum_circuit,
+                serializer=lambda buff, data: qpy_serialization.dump(data, buff))
             return {'__type__': 'Instruction', '__value__': value}
         if hasattr(obj, "settings"):
             return {'__type__': 'settings',
@@ -222,6 +282,15 @@ class RuntimeDecoder(json.JSONDecoder):
 
     def __init__(self, *args: Any, **kwargs: Any):
         super().__init__(object_hook=self.object_hook, *args, **kwargs)
+        self.__parameter_vectors: Dict[str, Tuple[ParameterVector, set]] = {}
+        self.__read_parameter_expression = (
+            functools.partial(
+                qpy_serialization._read_parameter_expression_v3,
+                vectors=self.__parameter_vectors,
+            )
+            if _TERRA_VERSION >= (0, 19, 1)
+            else qpy_serialization._read_parameter_expression
+        )
 
     def object_hook(self, obj: Any) -> Any:
         """Called to decode object."""
@@ -234,6 +303,8 @@ class RuntimeDecoder(json.JSONDecoder):
             if obj_type == 'complex':
                 return obj_val[0] + 1j * obj_val[1]
             if obj_type == 'ndarray':
+                if isinstance(obj_val, list):
+                    return np.array(obj_val)
                 return _decode_and_deserialize(obj_val, np.load)
             if obj_type == 'set':
                 return set(obj_val)
@@ -241,10 +312,14 @@ class RuntimeDecoder(json.JSONDecoder):
                 return _decode_and_deserialize(obj_val, qpy_serialization.load)[0]
             if obj_type == 'ParameterExpression':
                 return _decode_and_deserialize(
-                    obj_val, qpy_serialization._read_parameter_expression, False)
-            if obj_type == 'Instruction':
-                return _decode_and_deserialize(
-                    obj_val, qpy_serialization._read_instruction, False)
+                    obj_val, self.__read_parameter_expression, False
+                )
+            if obj_type == "Instruction":
+                # Standalone instructions are encoded as the sole
+                # instruction in a QPY serialized circuit to deserialize
+                # load qpy circuit and return first instruction object in that circuit.
+                circuit = _decode_and_deserialize(obj_val, qpy_serialization.load)[0]
+                return circuit.data[0][0]
             if obj_type == 'settings':
                 return deserialize_from_settings(
                     mod_name=obj['__module__'],
