@@ -64,16 +64,9 @@ class TestExperimentServerIntegration(IBMQTestCase):
         """Test level setup."""
         super().setUp()
         self.experiments_to_delete = []
-        self.results_to_delete = []
 
     def tearDown(self):
         """Test level tear down."""
-        for result_uuid in self.results_to_delete:
-            try:
-                with mock.patch('builtins.input', lambda _: 'y'):
-                    self.provider.experiment.delete_analysis_result(result_uuid)
-            except Exception as err:    # pylint: disable=broad-except
-                self.log.info("Unable to delete analysis result %s: %s", result_uuid, err)
         for expr_uuid in self.experiments_to_delete:
             try:
                 with mock.patch('builtins.input', lambda _: 'y'):
@@ -139,6 +132,21 @@ class TestExperimentServerIntegration(IBMQTestCase):
         self.assertTrue(found, "Experiment {} not found when filter by type {}.".format(
             exp_id, exp_type))
 
+    def test_experiments_with_parent_id(self):
+        """Test retrieving all experiments for a specific parent id."""
+        parent_id = self._create_experiment()
+        child_id = self._create_experiment(parent_id=parent_id)
+        experiments = self.provider.experiment.experiments(
+            parent_id=parent_id)
+
+        found = False
+        for exp in experiments:
+            self.assertEqual(parent_id, exp["parent_id"])
+            if exp["experiment_id"] == child_id:
+                found = True
+        self.assertTrue(found, "Experiment {} not found when filter by type {}.".format(
+            child_id, parent_id))
+
     def test_experiments_with_type_operator(self):
         """Test retrieving all experiments for a specific type with operator."""
         exp_type = 'qiskit_test'
@@ -168,7 +176,7 @@ class TestExperimentServerIntegration(IBMQTestCase):
                 experiment_type="foo", experiment_type_operator="bad")
 
     def test_experiments_with_start_time(self):
-        """Test retrieving all experiments for a specific type."""
+        """Test retrieving an experiment by its start_time."""
         ref_start_dt = datetime.now() - timedelta(days=1)
         ref_start_dt = ref_start_dt.replace(tzinfo=tz.tzlocal())
         exp_id = self._create_experiment(start_datetime=ref_start_dt)
@@ -186,7 +194,8 @@ class TestExperimentServerIntegration(IBMQTestCase):
         for start_dt, end_dt, expected, title in sub_tests:
             with self.subTest(title=title):
                 backend_experiments = self.provider.experiment.experiments(
-                    start_datetime_after=start_dt, start_datetime_before=end_dt)
+                    start_datetime_after=start_dt, start_datetime_before=end_dt,
+                    experiment_type='qiskit_test')
                 found = False
                 for exp in backend_experiments:
                     if start_dt:
@@ -559,7 +568,6 @@ class TestExperimentServerIntegration(IBMQTestCase):
             result_id=result_id,
             chisq=chisq
         )
-        self.results_to_delete.append(aresult_id)
 
         rresult = self.provider.experiment.analysis_result(aresult_id)
         self.assertEqual(exp_id, rresult["experiment_id"])
@@ -1040,7 +1048,6 @@ class TestExperimentServerIntegration(IBMQTestCase):
             result_type=result_type,
             **kwargs
         )
-        self.results_to_delete.append(aresult_id)
         return aresult_id
 
     def _find_backend_device_components(self, min_components):
