@@ -40,12 +40,12 @@ from qiskit.algorithms.optimizers import (
 from qiskit.result import Result
 from qiskit.circuit import Parameter, QuantumCircuit
 from qiskit.test.reference_circuits import ReferenceCircuits
-from qiskit.circuit.library import EfficientSU2
+from qiskit.circuit.library import EfficientSU2, CXGate, PhaseGate, U2Gate
 from qiskit.opflow import (PauliSumOp, MatrixOp, PauliOp, CircuitOp, EvolvedOp,
                            TaperedPauliSumOp, Z2Symmetries, I, X, Y, Z,
                            StateFn, CircuitStateFn, DictStateFn, VectorStateFn, OperatorStateFn,
                            SparseVectorStateFn, CVaRMeasurement, ComposedOp, SummedOp, TensoredOp)
-from qiskit.quantum_info import SparsePauliOp, Pauli, PauliTable, Statevector
+from qiskit.quantum_info import SparsePauliOp, Pauli, Statevector
 from qiskit.providers.jobstatus import JobStatus
 from qiskit.providers.ibmq.exceptions import IBMQInputValueError
 from qiskit.providers.ibmq.accountprovider import AccountProvider
@@ -180,8 +180,6 @@ class TestRuntime(IBMQTestCase):
         y = x + 1
         qc = QuantumCircuit(1)
         qc.h(0)
-        coeffs = np.array([1, 2, 3, 4, 5, 6])
-        table = PauliTable.from_labels(["III", "IXI", "IYY", "YIZ", "XYZ", "III"])
         op = (2.0 * I ^ I)
         z2_symmetries = Z2Symmetries(
             [Pauli("IIZI"), Pauli("ZIII")], [Pauli("IIXI"), Pauli("XIII")], [1, 3], [-1, 1]
@@ -194,7 +192,6 @@ class TestRuntime(IBMQTestCase):
             PauliSumOp(SparsePauliOp(Pauli("XYZX"), coeffs=[1]), coeff=y),
             PauliSumOp(SparsePauliOp(Pauli("XYZX"), coeffs=[1 + 2j]), coeff=3 - 2j),
             PauliSumOp.from_list([("II", -1.052373245772859), ("IZ", 0.39793742484318045)]),
-            PauliSumOp(SparsePauliOp(table, coeffs), coeff=10),
             MatrixOp(primitive=np.array([[0, -1j], [1j, 0]]), coeff=x),
             PauliOp(primitive=Pauli("Y"), coeff=x),
             CircuitOp(qc, coeff=x),
@@ -257,13 +254,40 @@ class TestRuntime(IBMQTestCase):
             decoded = json.loads(encoded, cls=RuntimeDecoder)
             self.assertEqual(decoded, obj)
 
+    def test_encoder_ndarray(self):
+        """Test encoding and decoding a numpy ndarray."""
+        subtests = (
+            {"ndarray": np.array([[1, 2, 3], [{"obj": 123}, 5, 6]], dtype=object)},
+            {"ndarray": np.array([[1, 2, 3], [{"obj": 123}, 5, 6]])},
+            {"ndarray": np.array([[1, 2, 3], [4, 5, 6], [7, 8, 9]], dtype=int)},
+        )
+        for obj in subtests:
+            encoded = json.dumps(obj, cls=RuntimeEncoder)
+            self.assertIsInstance(encoded, str)
+            decoded = json.loads(encoded, cls=RuntimeDecoder)
+            self.assertTrue(np.array_equal(decoded["ndarray"], obj["ndarray"]))
+
+    def test_encoder_instruction(self):
+        """Test encoding and decoding instructions"""
+        subtests = (
+            {"instruction": CXGate()},
+            {"instruction": PhaseGate(theta=1)},
+            {"instruction": U2Gate(phi=1, lam=1)},
+            {"instruction": U2Gate(phi=Parameter("phi"), lam=Parameter("lambda"))},
+        )
+        for obj in subtests:
+            encoded = json.dumps(obj, cls=RuntimeEncoder)
+            self.assertIsInstance(encoded, str)
+            decoded = json.loads(encoded, cls=RuntimeDecoder)
+            self.assertEqual(decoded, obj)
+
     def test_encoder_callable(self):
         """Test encoding a callable."""
         with warnings.catch_warnings(record=True) as warn_cm:
             encoded = json.dumps({"fidelity": lambda x: x}, cls=RuntimeEncoder)
             decoded = json.loads(encoded, cls=RuntimeDecoder)
             self.assertIsNone(decoded["fidelity"])
-            self.assertEqual(len(warn_cm), 1)
+            self.assertEqual(len(warn_cm), 2)
 
     def test_decoder_import(self):
         """Test runtime decoder importing modules."""
@@ -441,6 +465,12 @@ if __name__ == '__main__':
         self.assertTrue(job.result())
         self.assertEqual(job.image, image)
 
+    def test_run_program_with_custom_log_level(self):
+        """Test running program with a custom log level."""
+        job = self._run_program(log_level="DEBUG")
+        job_raw = self.runtime._api_client._get_job(job.job_id())
+        self.assertEqual(job_raw.log_level, "DEBUG")
+
     def test_retrieve_program_data(self):
         """Test retrieving program data"""
         program_id = self._upload_program(name="qiskit-test")
@@ -739,9 +769,11 @@ if __name__ == '__main__':
         return program_id
 
     def _run_program(self, program_id=None, inputs=None, job_classes=None, final_status=None,
-                     decoder=None, image=""):
+                     decoder=None, image="", log_level=None):
         """Run a program."""
         options = {'backend_name': "some_backend"}
+        if log_level:
+            options["log_level"] = log_level
         if final_status is not None:
             self.runtime._api_client.set_final_status(final_status)
         elif job_classes:
