@@ -1,8 +1,6 @@
-# -*- coding: utf-8 -*-
-
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2017, 2018.
+# (C) Copyright IBM 2017, 2021.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -18,22 +16,25 @@ import logging
 import os
 import warnings
 from io import StringIO
-from contextlib import contextmanager
-from tempfile import NamedTemporaryFile
 from unittest import skipIf
 from unittest.mock import patch
-from requests_ntlm import HttpNtlmAuth
+from typing import Dict, Any
+import copy
 
+from requests_ntlm import HttpNtlmAuth
 from qiskit.providers.ibmq import IBMQ, IBMQFactory
 from qiskit.providers.ibmq.credentials import (
-    Credentials, discover_credentials, qconfig,
-    read_credentials_from_qiskitrc, store_credentials)
+    Credentials, discover_credentials,
+    read_credentials_from_qiskitrc, store_credentials,
+    store_preferences, HubGroupProject)
 from qiskit.providers.ibmq.credentials.updater import (
     update_credentials, QE2_AUTH_URL, QE2_URL, QE_URL)
+from qiskit.providers.ibmq.credentials import configrc
 from qiskit.providers.ibmq.exceptions import IBMQAccountError
 
 from ..ibmqtestcase import IBMQTestCase
-from ..contextmanagers import custom_envs, no_envs, custom_qiskitrc, no_file, CREDENTIAL_ENV_VARS
+from ..contextmanagers import (custom_envs, no_envs, custom_qiskitrc, CREDENTIAL_ENV_VARS,
+                               mock_ibmq_provider)
 
 
 IBMQ_TEMPLATE = 'https://localhost/api/Hubs/{}/Groups/{}/Projects/{}'
@@ -51,15 +52,16 @@ PROXIES = {
 class TestCredentials(IBMQTestCase):
     """Tests for the credential modules."""
 
-    def test_autoregister_no_credentials(self):
-        """Test ``register()`` with no credentials available."""
-        with no_file('Qconfig.py'), custom_qiskitrc(), no_envs(CREDENTIAL_ENV_VARS):
+    def test_load_account_no_credentials(self) -> None:
+        """Test ``load_account()`` with no credentials available."""
+        with custom_qiskitrc(), no_envs(CREDENTIAL_ENV_VARS):
             with self.assertRaises(IBMQAccountError) as context_manager:
                 IBMQ.load_account()
 
-        self.assertIn('No IBM Quantum Experience credentials found', str(context_manager.exception))
+        self.assertIn('No IBM Quantum Experience credentials found',
+                      str(context_manager.exception))
 
-    def test_store_credentials_overwrite(self):
+    def test_store_credentials_overwrite(self) -> None:
         """Test overwriting qiskitrc credentials."""
         credentials = Credentials('QISKITRC_TOKEN', url=QE2_AUTH_URL)
         credentials2 = Credentials('QISKITRC_TOKEN_2', url=QE2_AUTH_URL)
@@ -79,7 +81,7 @@ class TestCredentials(IBMQTestCase):
                 store_credentials(credentials)
                 self.assertIn('already present', log_records.output[0])
 
-            with no_file('Qconfig.py'), no_envs(CREDENTIAL_ENV_VARS), mock_ibmq_provider():
+            with no_envs(CREDENTIAL_ENV_VARS), mock_ibmq_provider():
                 # Attempt overwriting.
                 store_credentials(credentials2, overwrite=True)
                 factory.load_account()
@@ -87,46 +89,32 @@ class TestCredentials(IBMQTestCase):
         # Ensure that the credentials are the overwritten ones.
         self.assertEqual(factory._credentials, credentials2)
 
-    def test_environ_over_qiskitrc(self):
-        """Test order, without qconfig"""
+    def test_environ_over_qiskitrc(self) -> None:
+        """Test credential discovery order."""
         credentials = Credentials('QISKITRC_TOKEN', url=QE2_AUTH_URL)
 
         with custom_qiskitrc():
             # Prepare the credentials: both env and qiskitrc present
             store_credentials(credentials)
-            with no_file('Qconfig.py'), custom_envs({'QE_TOKEN': 'ENVIRON_TOKEN',
-                                                     'QE_URL': 'ENVIRON_URL'}):
+            with custom_envs({'QE_TOKEN': 'ENVIRON_TOKEN',
+                              'QE_URL': 'ENVIRON_URL'}):
                 credentials, _ = discover_credentials()
 
         self.assertEqual(len(credentials), 1)
         self.assertEqual(list(credentials.values())[0].token, 'ENVIRON_TOKEN')
 
-    def test_qconfig_over_all(self):
-        """Test order, with qconfig"""
-        credentials = Credentials('QISKITRC_TOKEN', url=QE2_AUTH_URL)
-
-        with custom_qiskitrc():
-            # Prepare the credentials: qconfig, env and qiskitrc present
-            store_credentials(credentials)
-            with custom_qconfig(b"APItoken='QCONFIG_TOKEN'"),\
-                    custom_envs({'QE_TOKEN': 'ENVIRON_TOKEN'}):
-                credentials, _ = discover_credentials()
-
-        self.assertEqual(len(credentials), 1)
-        self.assertEqual(list(credentials.values())[0].token, 'QCONFIG_TOKEN')
-
 
 class TestCredentialsKwargs(IBMQTestCase):
     """Test for ``Credentials.connection_parameters()``."""
 
-    def test_no_proxy_params(self):
+    def test_no_proxy_params(self) -> None:
         """Test when no proxy parameters are passed."""
         no_params_expected_result = {'verify': True}
         no_params_credentials = Credentials('dummy_token', 'https://dummy_url')
         result = no_params_credentials.connection_parameters()
         self.assertDictEqual(no_params_expected_result, result)
 
-    def test_verify_param(self):
+    def test_verify_param(self) -> None:
         """Test 'verify' arg is acknowledged."""
         false_verify_expected_result = {'verify': False}
         false_verify_credentials = Credentials(
@@ -134,7 +122,7 @@ class TestCredentialsKwargs(IBMQTestCase):
         result = false_verify_credentials.connection_parameters()
         self.assertDictEqual(false_verify_expected_result, result)
 
-    def test_proxy_param(self):
+    def test_proxy_param(self) -> None:
         """Test using only proxy urls (no NTLM credentials)."""
         urls = {'http': 'localhost:8080', 'https': 'localhost:8080'}
         proxies_only_expected_result = {'verify': True, 'proxies': urls}
@@ -143,7 +131,7 @@ class TestCredentialsKwargs(IBMQTestCase):
         result = proxies_only_credentials.connection_parameters()
         self.assertDictEqual(proxies_only_expected_result, result)
 
-    def test_proxies_param_with_ntlm(self):
+    def test_proxies_param_with_ntlm(self) -> None:
         """Test proxies with NTLM credentials."""
         urls = {'http': 'localhost:8080', 'https': 'localhost:8080'}
         proxies_with_ntlm_dict = {
@@ -171,7 +159,7 @@ class TestCredentialsKwargs(IBMQTestCase):
         result.pop('auth')
         self.assertDictEqual(ntlm_expected_result, result)
 
-    def test_malformed_proxy_param(self):
+    def test_malformed_proxy_param(self) -> None:
         """Test input with malformed nesting of the proxies dictionary."""
         urls = {'http': 'localhost:8080', 'https': 'localhost:8080'}
         malformed_nested_proxies_dict = {'proxies': urls}
@@ -184,7 +172,7 @@ class TestCredentialsKwargs(IBMQTestCase):
         result = malformed_nested_credentials.connection_parameters()
         self.assertDictEqual(expected_result, result)
 
-    def test_malformed_ntlm_params(self):
+    def test_malformed_ntlm_params(self) -> None:
         """Test input with malformed NTLM credentials."""
         urls = {'http': 'localhost:8080', 'https': 'localhost:8080'}
         malformed_ntlm_credentials_dict = {
@@ -201,11 +189,158 @@ class TestCredentialsKwargs(IBMQTestCase):
             _ = malformed_ntlm_credentials.connection_parameters()
 
 
+@skipIf(os.name == 'nt', 'Test not supported in Windows')
+class TestPreferences(IBMQTestCase):
+    """Tests for the preferences."""
+
+    def test_save_preferences(self):
+        """Test saving preferences."""
+        preferences = self._get_pref_dict()
+        with custom_qiskitrc():
+            store_preferences(preferences)
+            _, stored_pref = read_credentials_from_qiskitrc()
+            self.assertEqual(preferences, stored_pref)
+
+    def test_update_preferences(self):
+        """Test updating preferences."""
+        pref1 = self._get_pref_dict()
+        with custom_qiskitrc():
+            store_preferences(pref1)
+            pref2 = self._get_pref_dict(pref_val=False)
+            store_preferences(pref2)
+            _, stored_pref = read_credentials_from_qiskitrc()
+            self.assertEqual(pref2, stored_pref)
+
+    def test_new_provider_pref(self):
+        """Test adding preference for another provider."""
+        pref1 = self._get_pref_dict()
+        with custom_qiskitrc():
+            store_preferences(pref1)
+            pref2 = self._get_pref_dict('hub2/group2/project2', pref_val=False)
+            store_preferences(pref2)
+            _, stored_pref = read_credentials_from_qiskitrc()
+            self.assertEqual({**pref1, **pref2}, stored_pref)
+
+    def test_update_one_of_many_providers(self):
+        """Test updating one of many provider preferences."""
+        pref1 = self._get_pref_dict(pref_val=False)
+        pref2 = self._get_pref_dict('hub2/group2/project2', pref_val=False)
+        with custom_qiskitrc():
+            store_preferences(pref1)
+            store_preferences(pref2)
+            pref1 = self._get_pref_dict(pref_val=True)
+            store_preferences(pref1)
+
+            _, stored_pref = read_credentials_from_qiskitrc()
+            self.assertEqual({**pref1, **pref2}, stored_pref)
+
+    def test_save_same_value_twice(self):
+        """Test saving same value twice."""
+        pref = self._get_pref_dict(pref_val=True)
+        with custom_qiskitrc():
+            store_preferences(pref)
+            store_preferences(pref)
+
+            _, stored_pref = read_credentials_from_qiskitrc()
+            self.assertEqual(pref, stored_pref)
+
+    def test_new_pref_cat(self):
+        """Test adding a new preference category."""
+        pref1 = self._get_pref_dict()
+        orig_active_pref = copy.deepcopy(configrc._ACTIVE_PREFERENCES)
+        try:
+            configrc._ACTIVE_PREFERENCES.update(
+                {'foo': {'bar': str}})
+            with custom_qiskitrc():
+                store_preferences(pref1)
+                new_cat = self._get_pref_dict(cat="foo", pref_key="bar", pref_val='foobar')
+                store_preferences(new_cat)
+                _, stored_pref = read_credentials_from_qiskitrc()
+
+                key = list(pref1.keys())[0]
+                pref1[key].update(new_cat[key])
+                self.assertEqual(pref1, stored_pref)
+        finally:
+            configrc._ACTIVE_PREFERENCES = orig_active_pref
+
+    def test_overwrite_category_keys(self):
+        """Test overwriting preference keys in a category."""
+        pref1 = self._get_pref_dict()
+        orig_active_pref = copy.deepcopy(configrc._ACTIVE_PREFERENCES)
+        try:
+            configrc._ACTIVE_PREFERENCES['experiment'].update({'foo': str})
+            with custom_qiskitrc():
+                store_preferences(pref1)
+                new_cat = self._get_pref_dict(pref_key="foo", pref_val='bar')
+                store_preferences(new_cat)
+                _, stored_pref = read_credentials_from_qiskitrc()
+
+                key = list(pref1.keys())[0]
+                pref1[key]['experiment'] = {'foo': 'bar'}
+                self.assertEqual(pref1, stored_pref)
+        finally:
+            configrc._ACTIVE_PREFERENCES = orig_active_pref
+
+    def test_save_preferences_credentials(self):
+        """Test saving both preferences and credentials."""
+        preferences = self._get_pref_dict()
+        credentials = Credentials('QISKITRC_TOKEN', url=QE2_AUTH_URL)
+        with custom_qiskitrc():
+            store_preferences(preferences)
+            store_credentials(credentials)
+            stored_cred, stored_pref = read_credentials_from_qiskitrc()
+            self.assertEqual(preferences, stored_pref)
+            self.assertEqual(credentials, stored_cred[credentials.unique_id()])
+
+    def test_update_preferences_with_credentials(self):
+        """Test updating preferences with credentials."""
+        preferences = self._get_pref_dict()
+        pref2 = self._get_pref_dict(pref_val=False)
+        credentials = Credentials('QISKITRC_TOKEN', url=QE2_AUTH_URL)
+        credentials2 = Credentials('QISKITRC_TOKEN_2', url=QE2_AUTH_URL)
+        with custom_qiskitrc():
+            store_preferences(preferences)
+            store_credentials(credentials)
+            # Update preferences.
+            store_preferences(pref2)
+            stored_cred, stored_pref = read_credentials_from_qiskitrc()
+            self.assertEqual(pref2, stored_pref)
+            self.assertEqual(credentials, stored_cred[credentials.unique_id()])
+            # Update credentials.
+            store_credentials(credentials2, overwrite=True)
+            stored_cred, stored_pref = read_credentials_from_qiskitrc()
+            self.assertEqual(pref2, stored_pref)
+            self.assertEqual(credentials2, stored_cred[credentials2.unique_id()])
+
+    def test_remove_credentials(self):
+        """Test removing credentials when preferences are set."""
+        preferences = self._get_pref_dict()
+        credentials = Credentials('QISKITRC_TOKEN', url=QE2_AUTH_URL)
+        with custom_qiskitrc():
+            store_credentials(credentials)
+            store_preferences(preferences)
+            configrc.remove_credentials(credentials)
+            stored_cred, stored_pref = read_credentials_from_qiskitrc()
+            self.assertEqual(preferences, stored_pref)
+            self.assertFalse(stored_cred)
+
+    def _get_pref_dict(
+            self,
+            hgp: str = 'my-hub/my-group/my-project',
+            cat: str = 'experiment',
+            pref_key: str = 'auto_save',
+            pref_val: Any = True
+    ) -> Dict:
+        """Generate a new preference dictionary."""
+        hub, group, project = hgp.split('/')
+        return {HubGroupProject(hub, group, project): {cat: {pref_key: pref_val}}}
+
+
 @skipIf(os.name == 'nt', 'Test not supported in Windows')
 class TestIBMQAccountUpdater(IBMQTestCase):
     """Tests for the ``update_credentials()`` helper."""
 
-    def setUp(self):
+    def setUp(self) -> None:
         """Initial test setup."""
         super().setUp()
 
@@ -213,14 +348,14 @@ class TestIBMQAccountUpdater(IBMQTestCase):
         self.patcher = patch('sys.stdout', new=StringIO())
         self.patcher.start()
 
-    def tearDown(self):
+    def tearDown(self) -> None:
         """Test cleanup."""
         super().tearDown()
 
         # Reenable stdout output.
         self.patcher.stop()
 
-    def assertCorrectApi2Credentials(self, token, credentials_dict):
+    def assertCorrectApi2Credentials(self, token, credentials_dict) -> None:
         """Asserts that there is only one credentials belonging to API 2."""
         self.assertEqual(len(credentials_dict), 1)
         credentials = list(credentials_dict.values())[0]
@@ -231,7 +366,7 @@ class TestIBMQAccountUpdater(IBMQTestCase):
         if token:
             self.assertEqual(credentials.token, token)
 
-    def test_qe_credentials(self):
+    def test_qe_credentials(self) -> None:
         """Test converting QE credentials."""
         with custom_qiskitrc():
             store_credentials(Credentials('A', url=QE_URL))
@@ -241,7 +376,7 @@ class TestIBMQAccountUpdater(IBMQTestCase):
             loaded_accounts, _ = read_credentials_from_qiskitrc()
             self.assertCorrectApi2Credentials('A', loaded_accounts)
 
-    def test_qconsole_credentials(self):
+    def test_qconsole_credentials(self) -> None:
         """Test converting Qconsole credentials."""
         with custom_qiskitrc():
             store_credentials(Credentials('A',
@@ -252,7 +387,7 @@ class TestIBMQAccountUpdater(IBMQTestCase):
             loaded_accounts, _ = read_credentials_from_qiskitrc()
             self.assertCorrectApi2Credentials('A', loaded_accounts)
 
-    def test_proxy_credentials(self):
+    def test_proxy_credentials(self) -> None:
         """Test converting credentials with proxy values."""
         with custom_qiskitrc():
             store_credentials(Credentials('A',
@@ -268,7 +403,7 @@ class TestIBMQAccountUpdater(IBMQTestCase):
             credentials = list(loaded_accounts.values())[0]
             self.assertEqual(credentials.proxies, PROXIES)
 
-    def test_multiple_credentials(self):
+    def test_multiple_credentials(self) -> None:
         """Test converting multiple credentials."""
         with custom_qiskitrc():
             store_credentials(Credentials('A', url=QE2_AUTH_URL))
@@ -284,7 +419,7 @@ class TestIBMQAccountUpdater(IBMQTestCase):
             # the qiskitrc, which is not guaranteed.
             self.assertCorrectApi2Credentials(None, loaded_accounts)
 
-    def test_api2_non_auth_credentials(self):
+    def test_api2_non_auth_credentials(self) -> None:
         """Test converting api 2 non auth credentials."""
         with custom_qiskitrc():
             store_credentials(Credentials('A', url=QE2_URL))
@@ -294,7 +429,7 @@ class TestIBMQAccountUpdater(IBMQTestCase):
             loaded_accounts, _ = read_credentials_from_qiskitrc()
             self.assertCorrectApi2Credentials('A', loaded_accounts)
 
-    def test_auth2_credentials(self):
+    def test_auth2_credentials(self) -> None:
         """Test converting already API 2 auth credentials."""
         with custom_qiskitrc():
             store_credentials(Credentials('A', url=QE2_AUTH_URL))
@@ -303,7 +438,7 @@ class TestIBMQAccountUpdater(IBMQTestCase):
             # No credentials should be returned.
             self.assertIsNone(credentials)
 
-    def test_unknown_credentials(self):
+    def test_unknown_credentials(self) -> None:
         """Test converting credentials with an unknown URL."""
         with custom_qiskitrc():
             store_credentials(Credentials('A', url='UNKNOWN_URL'))
@@ -314,44 +449,3 @@ class TestIBMQAccountUpdater(IBMQTestCase):
             loaded_accounts, _ = read_credentials_from_qiskitrc()
             self.assertEqual(list(loaded_accounts.values())[0].url,
                              'UNKNOWN_URL')
-
-
-# Context managers
-
-
-@contextmanager
-def custom_qconfig(contents=b''):
-    """Context manager that uses a temporary qconfig.py."""
-    # Create a temporary file with the contents.
-    tmp_file = NamedTemporaryFile(suffix='.py')
-    tmp_file.write(contents)
-    tmp_file.flush()
-
-    # Temporarily modify the default location of the qiskitrc file.
-    default_qconfig_file_original = qconfig.DEFAULT_QCONFIG_FILE
-    qconfig.DEFAULT_QCONFIG_FILE = tmp_file.name
-    yield
-
-    # Delete the temporary file and restore the default location.
-    tmp_file.close()
-    qconfig.DEFAULT_QCONFIG_FILE = default_qconfig_file_original
-
-
-def _mocked_initialize_provider(self, credentials: Credentials):
-    """Mock ``_initialize_provider()``, just storing the credentials."""
-    self._credentials = credentials
-
-
-@contextmanager
-def mock_ibmq_provider():
-    """Mock the initialization of ``IBMQFactory``, so it does not query the API."""
-    patcher = patch.object(IBMQFactory, '_initialize_providers',
-                           side_effect=_mocked_initialize_provider,
-                           autospec=True)
-    patcher2 = patch.object(IBMQFactory, '_check_api_version',
-                            return_value={'new_api': True, 'api-auth': '0.1'})
-    patcher.start()
-    patcher2.start()
-    yield
-    patcher2.stop()
-    patcher.stop()
