@@ -1,8 +1,6 @@
-# -*- coding: utf-8 -*-
-
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2018, 2019.
+# (C) Copyright IBM 2018, 2021.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -18,16 +16,18 @@ from unittest import mock
 from threading import Thread
 from queue import Queue
 
+from qiskit import transpile
+from qiskit.test.reference_circuits import ReferenceCircuits
 from qiskit.test import slow_test
 from qiskit.providers import JobTimeoutError
-from qiskit.providers.ibmq.api.clients.websocket import (
-    WebsocketClient, WebsocketAuthenticationMessage)
+from qiskit.providers.ibmq.api.clients import websocket
 from qiskit.providers.ibmq.api.clients import AccountClient
 from qiskit.providers.jobstatus import JobStatus
 
 from ...ibmqtestcase import IBMQTestCase
 from ...decorators import requires_provider, requires_device
-from ...utils import most_busy_backend, bell_in_qobj, cancel_job
+from ...utils import most_busy_backend, cancel_job
+from ...proxy_server import MockProxyServer, use_proxies
 
 
 class TestWebsocketIntegration(IBMQTestCase):
@@ -41,7 +41,7 @@ class TestWebsocketIntegration(IBMQTestCase):
         super().setUpClass()
         cls.provider = provider
         cls.sim_backend = provider.get_backend('ibmq_qasm_simulator')
-        cls.qobj = bell_in_qobj(cls.sim_backend, shots=1)
+        cls.bell = transpile(ReferenceCircuits.bell(), cls.sim_backend)
 
     def setUp(self):
         """Initial test setup."""
@@ -60,7 +60,7 @@ class TestWebsocketIntegration(IBMQTestCase):
 
     def test_websockets_simulator(self):
         """Test checking status of a job via websockets for a simulator."""
-        job = self.sim_backend.run(self.qobj, validate_qobj=True)
+        job = self.sim_backend.run(self.bell, shots=1)
 
         # Manually disable the non-websocket polling.
         job._api_client._job_final_status_polling = self._job_final_status_polling
@@ -72,8 +72,7 @@ class TestWebsocketIntegration(IBMQTestCase):
     @requires_device
     def test_websockets_device(self, backend):
         """Test checking status of a job via websockets for a device."""
-        qobj = bell_in_qobj(backend=backend, shots=1)
-        job = backend.run(qobj, validate_qobj=True)
+        job = backend.run(transpile(ReferenceCircuits.bell(), backend), shots=1)
 
         # Manually disable the non-websocket polling.
         job._api_client._job_final_status_polling = self._job_final_status_polling
@@ -84,7 +83,7 @@ class TestWebsocketIntegration(IBMQTestCase):
 
     def test_websockets_job_final_state(self):
         """Test checking status of a job in a final state via websockets."""
-        job = self.sim_backend.run(self.qobj, validate_qobj=True)
+        job = self.sim_backend.run(self.bell)
 
         job._wait_for_completion()
 
@@ -99,29 +98,29 @@ class TestWebsocketIntegration(IBMQTestCase):
 
     def test_websockets_retry_bad_url(self):
         """Test http retry after websocket error due to an invalid URL."""
-        job = self.sim_backend.run(self.qobj, validate_qobj=True)
 
-        saved_websocket_url = job._api_client.client_ws.websocket_url
+        job = self.sim_backend.run(self.bell)
+        saved_websocket_url = job._api_client._credentials.websockets_url
+
         try:
             # Use fake websocket address.
-            job._api_client.client_ws.websocket_url = 'wss://wss.localhost'
+            job._api_client._credentials.websockets_url = 'wss://wss.localhost'
 
             # _wait_for_completion() should retry with http successfully
             # after getting websockets error.
             job._wait_for_completion()
         finally:
-            job._api_client.client_ws.websocket_url = saved_websocket_url
+            job._api_client._credentials.websockets_url = saved_websocket_url
 
         self.assertIs(job._status, JobStatus.DONE)
 
-    @mock.patch.object(WebsocketClient, '_authentication_message',
-                       return_value=WebsocketAuthenticationMessage(
-                           type_='authentication', data='phantom_token'))
-    def test_websockets_retry_bad_auth(self, _):
+    def test_websockets_retry_bad_auth(self):
         """Test http retry after websocket error due to a failed authentication."""
-        job = self.sim_backend.run(self.qobj, validate_qobj=True)
+        job = self.sim_backend.run(self.bell)
 
-        with mock.patch.object(AccountClient, 'job_status',
+        with mock.patch.object(websocket.WebsocketAuthenticationMessage, 'as_json',
+                               return_value='foo'), \
+             mock.patch.object(AccountClient, 'job_status',
                                side_effect=job._api_client.job_status) as mocked_wait:
             job._wait_for_completion()
             self.assertIs(job._status, JobStatus.DONE)
@@ -136,7 +135,7 @@ class TestWebsocketIntegration(IBMQTestCase):
             job._job_id = saved_job_id
             return saved_job_status(saved_job_id)
 
-        job = self.sim_backend.run(self.qobj, validate_qobj=True)
+        job = self.sim_backend.run(self.bell)
 
         # Save the originals.
         saved_job_id = job._job_id
@@ -155,8 +154,8 @@ class TestWebsocketIntegration(IBMQTestCase):
     def test_websockets_timeout(self):
         """Test timeout checking status of a job via websockets."""
         backend = most_busy_backend(self.provider)
-        qobj = bell_in_qobj(backend, shots=backend.configuration().max_shots)
-        job = backend.run(qobj, validate_qobj=True)
+        job = backend.run(transpile(ReferenceCircuits.bell(), backend),
+                          shots=backend.configuration().max_shots)
 
         try:
             with self.assertRaises(JobTimeoutError):
@@ -169,7 +168,7 @@ class TestWebsocketIntegration(IBMQTestCase):
 
         def _run_job_get_result(q):
             """Run a job and get its result."""
-            job = self.sim_backend.run(self.qobj, validate_qobj=True)
+            job = self.sim_backend.run(self.bell)
             # Manually disable the non-websocket polling.
             job._api_client._job_final_status_polling = self._job_final_status_polling
             job._wait_for_completion()
@@ -193,3 +192,28 @@ class TestWebsocketIntegration(IBMQTestCase):
         if not result_q.empty():
             message = result_q.get_nowait()
             self.fail(message)
+
+    def test_websocket_proxy(self):
+        """Test connecting to websocket via a proxy."""
+        MockProxyServer(self, self.log).start()
+        job = self.sim_backend.run(self.bell, shots=1)
+
+        # Manually disable the non-websocket polling.
+        job._api_client._job_final_status_polling = self._job_final_status_polling
+        with use_proxies(self.provider, MockProxyServer.VALID_PROXIES):
+            result = job.result()
+
+        self.assertEqual(result.status, 'COMPLETED')
+
+    def test_websocket_proxy_invalid_port(self):
+        """Test connecting to websocket via invalid proxy port."""
+        MockProxyServer(self, self.log).start()
+        job = self.sim_backend.run(self.bell, shots=1)
+
+        invalid_proxy = {'https': 'http://{}:{}'.format(MockProxyServer.PROXY_IP_ADDRESS,
+                                                        MockProxyServer.INVALID_PROXY_PORT)}
+        with use_proxies(self.provider, invalid_proxy):
+            with self.assertLogs('qiskit.providers.ibmq', 'INFO') as log_cm:
+                job.wait_for_final_state()
+
+        self.assertIn("retrying using HTTP", ','.join(log_cm.output))
